<?php

/**
 * Auto create .css file from Theme Options
 * @author Fox
 * @version 1.0.0
 */
class CMSSuperHeroes_StaticCss
{

    public $scss;
    
    function __construct()
    {
        if(!class_exists('scssc'))
            return;

        /* scss */
        $this->scss = new scssc();
        
        /* set paths scss */
        $this->scss->setImportPaths(get_template_directory() . '/assets/scss/');
             
        /* generate css over time */
		add_action('wp', array($this, 'generate_over_time'));
        
        /* save option generate css */
       	add_action("redux/options/opt_wage_options/saved", array($this,'generate_file'));
    }
	
    public function generate_over_time(){
    	
    	global $opt_wage_options;

    	if (!empty($opt_wage_options) && $opt_wage_options['dev_mode']){
    	    $this->generate_file();
    	}
    }
    /**
     * generate css file.
     *
     * @since 1.0.0
     */
    public function generate_file()
    {
        global $opt_wage_options, $wp_filesystem;
        
        if (empty($wp_filesystem) || !isset($opt_wage_options))
            return;
            
        $options_scss = get_template_directory() . '/assets/scss/options.scss';

        /* delete files options.scss */
        $wp_filesystem->delete($options_scss);

        /* write options to scss file */
        $wp_filesystem->put_contents($options_scss, $this->css_render(), FS_CHMOD_FILE); // Save it

        /* minimize CSS styles */
        if (!$opt_wage_options['dev_mode'])
            $this->scss->setFormatter('scss_formatter_compressed');

        /* compile scss to css */
        $css = $this->scss_render();

        $file = "static.css";

        $file = get_template_directory() . '/assets/css/' . $file;

        /* delete files static.css */
        $wp_filesystem->delete($file);

        /* write static.css file */
        $wp_filesystem->put_contents($file, $css, FS_CHMOD_FILE); // Save it
    }
    
    /**
     * scss compile
     * 
     * @since 1.0.0
     * @return string
     */
    public function scss_render(){
        /* compile scss to css */
        return $this->scss->compile('@import "master.scss"');
    }
    
    /**
     * main css
     *
     * @since 1.0.0
     * @return string
     */
    public function css_render()
    {
        global $opt_wage_options,$opt_meta_options;
        
        ob_start();

        /* primary_color */
        if(!empty($opt_wage_options['primary_color']))
            echo '$primary_color:'.esc_attr($opt_wage_options['primary_color']).';';

        if(!empty($opt_wage_options['secondary_color']))
            echo '$secondary_color:'.esc_attr($opt_wage_options['secondary_color']).';';

        if(!empty($opt_wage_options['link_color_three']))
            echo '$link_color_three:'.esc_attr($opt_wage_options['link_color_three']).';';

         $link_color = (!empty($opt_wage_options['link_color']['regular']))?$opt_wage_options['link_color']['regular']:'#222';
         echo '$link_color:'.esc_attr($link_color).';'; 

         $link_color_hover = (!empty($opt_wage_options['link_color']['hover']))?$opt_wage_options['link_color']['hover']:'#01ce83';
         echo '$link_color_hover:'.esc_attr($link_color_hover).';';  


        $link_secondary_color = (!empty($opt_wage_options['link_secondary_color']))?$opt_wage_options['link_secondary_color']:'#aaacb5';
         echo '$link_secondary_color:'.esc_attr($link_secondary_color).';'; 

          /* logo_max_height */
        $header_max_height = (!empty($opt_wage_options['header_max_height']['height']))?$opt_wage_options['header_max_height']['height']:'108px';
         echo '$header_max_height:'.esc_attr($header_max_height).';';


        $logo_max_height = (!empty($opt_wage_options['logo_max_height']['height']))?$opt_wage_options['logo_max_height']['height']:'129px';
         echo '$logo_max_height:'.esc_attr($logo_max_height).';';

        $logo_max_height_sticky = (!empty($opt_wage_options['logo_max_height_sticky']['height']))?$opt_wage_options['logo_max_height_sticky']['height']:'103px';
         echo '$logo_max_height_sticky:'.esc_attr($logo_max_height_sticky).';'; 


         $topbar_max_height = (!empty($opt_wage_options['topbar_max_height']['height']))?$opt_wage_options['topbar_max_height']['height']:'50px';
         echo '$topbar_max_height:'.esc_attr($topbar_max_height).';'; 

         $menu_max_height = (!empty($opt_wage_options['menu_max_height']['height']))?$opt_wage_options['menu_max_height']['height']:'87px';
         echo '$menu_max_height:'.esc_attr($menu_max_height).';'; 


         /*header_link_color Full Screen Menu page Option*/ 

          $item_link_color_fullscreen = (!empty($opt_meta_options['item_link_color_fullscreen']['regular']))?$opt_meta_options['item_link_color_fullscreen']['regular']:'#fff';
         echo '$item_link_color_fullscreen:'.esc_attr($item_link_color_fullscreen).';';  

          $item_link_color_fullscreen_active = (!empty($opt_meta_options['item_link_color_fullscreen']['active']))?$opt_meta_options['item_link_color_fullscreen']['active']:'#222';
         echo '$item_link_color_fullscreen_active:'.esc_attr($item_link_color_fullscreen_active).';';  

          $item_link_color_fullscreen_hover = (!empty($opt_meta_options['item_link_color_fullscreen']['hover']))?$opt_meta_options['item_link_color_fullscreen']['hover']:'#222';
         echo '$item_link_color_fullscreen_hover:'.esc_attr($item_link_color_fullscreen_hover).';';  

         $fullmenu_max_height = (!empty($opt_meta_options['fullmenu_max_height']['height']))?$opt_meta_options['fullmenu_max_height']['height']:'129px';
         echo '$fullmenu_max_height:'.esc_attr($fullmenu_max_height).';'; 

         $fullmenu_max_height_sticky = (!empty($opt_meta_options['fullmenu_max_height_sticky']['height']))?$opt_meta_options['fullmenu_max_height_sticky']['height']:'87px';
         echo '$fullmenu_max_height_sticky:'.esc_attr($fullmenu_max_height_sticky).';'; 

           echo '.spacebody.admin-bar.hd-fixed .fullscreen-menu-wrap {
                top: calc('.$fullmenu_max_height_sticky.'  + 32px );
            }';
         /*header_link_color*/ 

          $header_link_color = (!empty($opt_wage_options['header_link_color']['regular']))?$opt_wage_options['header_link_color']['regular']:'#fff';
         echo '$header_link_color:'.esc_attr($header_link_color).';';  

          $header_link_color_active = (!empty($opt_wage_options['header_link_color']['active']))?$opt_wage_options['header_link_color']['active']:'#aaacb5';
         echo '$header_link_color_active:'.esc_attr($header_link_color_active).';';  

          $header_link_color_hover = (!empty($opt_wage_options['header_link_color']['hover']))?$opt_wage_options['header_link_color']['hover']:'#aaacb5';
         echo '$header_link_color_hover:'.esc_attr($header_link_color_hover).';';  

         $logo_background = (!empty($opt_wage_options['logo_background']['background-color']))?$opt_wage_options['logo_background']['background-color']:'#fff';
         echo '$logo_background:'.esc_attr($logo_background).';'; 
         $logo_background_layout2 = (!empty($opt_wage_options['logo_background_layout2']['background-color']))?$opt_wage_options['logo_background_layout2']['background-color']:'#fff';
         echo '$logo_background_layout2:'.esc_attr($logo_background_layout2).';'; 
          /*footer_top_link_color*/
          $footer_top_link_color_active = (!empty($opt_wage_options['footer_top_link_color']['active']))?$opt_wage_options['footer_top_link_color']['active']:'#e7e7e7';
         echo '$footer_top_link_color_active:'.esc_attr($footer_top_link_color_active).';';  

         $footer_top_background = (!empty($opt_wage_options['footer_top_background']['rgba']))?$opt_wage_options['footer_top_background']['rgba']:'rgba(34, 34, 34, 0.5)';
         echo '$footer_top_background:'.esc_attr($footer_top_background).';'; 


        $sticky_header_background_color = (!empty($opt_wage_options['sticky_header_background_color']['rgba']))?$opt_wage_options['sticky_header_background_color']['rgba']:'rgba(255, 255, 255, 1)';
         echo '$sticky_header_background_color:'.esc_attr($sticky_header_background_color).';'; 

         
         /* Page Title  */ 

         $pagetile_text_color = (!empty($opt_wage_options['pagetile_text_color']))?$opt_wage_options['pagetile_text_color']:'#25ae60';
         echo '$pagetile_text_color:'.esc_attr($pagetile_text_color).';'; 

          $pagetile_link_color = (!empty($opt_wage_options['pagetile_link_color']['regular']))?$opt_wage_options['pagetile_link_color']['regular']:'#aaacb5';
         echo '$pagetile_link_color:'.esc_attr($pagetile_link_color).';';  

          $pagetile_link_color_active = (!empty($opt_wage_options['pagetile_link_color']['active']))?$opt_wage_options['pagetile_link_color']['active']:'#fff';
         echo '$pagetile_link_color_active:'.esc_attr($pagetile_link_color_active).';';  

          $pagetile_link_color_hover = (!empty($opt_wage_options['pagetile_link_color']['hover']))?$opt_wage_options['pagetile_link_color']['hover']:'#fff';
         echo '$pagetile_link_color_hover:'.esc_attr($pagetile_link_color_hover).';';  

         $pagetile_text_color_overlay = (!empty($opt_wage_options['pagetile_text_color_overlay']['rgba']))?$opt_wage_options['pagetile_text_color_overlay']['rgba']:'rgba(34, 34, 34, 0.7)';
         echo '$pagetile_text_color_overlay:'.esc_attr($pagetile_text_color_overlay).';';  

         
         /* Typo  */
        
        if(!empty($opt_wage_options['font_body']['color']))
            echo '$font_body_color:'.esc_attr($opt_wage_options['font_body']['color']).';';

         /* Error - Comming  */
          $comming_overlay = (!empty($opt_wage_options['comming_overlay']['rgba']))?$opt_wage_options['comming_overlay']['rgba']:'rgba(34, 34, 34, 0.6)';
         echo '$comming_overlay:'.esc_attr($comming_overlay).';';  

          $error_overlay = (!empty($opt_wage_options['error_overlay']['rgba']))?$opt_wage_options['error_overlay']['rgba']:'rgba(34, 34, 34, 0.6)';
         echo '$error_overlay:'.esc_attr($error_overlay).';';  
         
          $maintenance_overlay = (!empty($opt_wage_options['maintenance_overlay']['rgba']))?$opt_wage_options['maintenance_overlay']['rgba']:'rgba(34, 34, 34, 0.6)';
         echo '$maintenance_overlay:'.esc_attr($maintenance_overlay).';';  
         
        return ob_get_clean();
    }
}

new CMSSuperHeroes_StaticCss();