<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (! class_exists('Redux')) {
    return;
}

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('opt_name', 'opt_wage_options');

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => $theme->get('Name'),
    'page_title' => $theme->get('Name'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    // 'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-smiley',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    // 'open_expanded' => true, // Allow you to start the panel in an expanded way initially.
    'disable_save_warn' => true, // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => 'dashicons-dashboard',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'dashicons-smiley',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit' => '', // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => ''
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right'
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover'
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave'
            )
        )
    )
);

Redux::setArgs($opt_name, $args);

/**
 * General Options.
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('General', 'wpwage'),
    'icon' => 'el-icon-adjust-alt',
    'fields' => array(
        array(
            'title'             => esc_html__('Layout', 'wpwage'),
            'subtitle'          => esc_html__('Full width / Boxed.', 'wpwage'),
            'id'                => 'general_layout',
            'type'              => 'button_set',
            'options'           => array(
                                        1 => esc_html__('Full width', 'wpwage'),
                                        2 => esc_html__('Boxed', 'wpwage')
                                    ),
            'default'           => 1
        ),
        array(
            'title'             => esc_html__('Body Background', 'wpwage'),
            'subtitle'          => esc_html__('Body background.', 'wpwage'),
            'id'                => 'general_background',
            'type'              => 'background',
            'output'            => array( 'body ' ),
            'required'          => array( 'general_layout', '=', 1 ),
            'default'  => array(
                    'background-color' => '#fff',
                )
        ),
        array(
            'title'             => esc_html__('Content Background', 'wpwage'),
            'subtitle'          => esc_html__('Content background.', 'wpwage'),
            'id'                => 'general_content_background',
            'type'              => 'background',
            'output'            => array( '#content .container' ),
            'required'          => array( 'general_layout', '=', 1 ),
             'default'  => array(
                    'background-color' => '#fff',
                )
        ),
        array(
            'title'             => esc_html__('Body Background', 'wpwage'),
            'subtitle'          => esc_html__('Body background.', 'wpwage'),
            'id'                => 'general_background_boxed',
            'type'              => 'background',
            'output'            => array( 'body.boxed .wrapper' ),
            'required'          => array( 'general_layout', '=', 2 ),
            'default'  => array(
                    'background-color' => '#fff',
                )
        ),
        array(
            'title'             => esc_html__('Content Background', 'wpwage'),
            'subtitle'          => esc_html__('Content background.', 'wpwage'),
            'id'                => 'general_content_background_boxed',
            'type'              => 'background',
            'output'            => array( '.boxed #content .container' ),
            'required'          => array( 'general_layout', '=', 2 ),
             'default'  => array(
                    'background-color' => '#fff',
                )
        ),
         array(
            'title' => 'Select Favicon',
            'id' => 'favicon_icon',
            'type' => 'media',
            'url' => true,
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/favicon.png'
            )
        ),
    )
));

/**
 * Header Options
 * 
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Header', 'wpwage'),
    'icon' => 'el-icon-credit-card',
    'fields' => array(
        array(
            'id'                => 'header_layout',
            'title'             => esc_html__('Layouts', 'wpwage'),
            'subtitle'          => esc_html__('select a layout for header', 'wpwage'),
            'default'           => 'layout1',
            'type'              => 'image_select',
            'options'           => array(
                                        'default' => get_template_directory_uri().'/assets/images/header/default.jpg',
                                        'layout1' => get_template_directory_uri().'/assets/images/header/layout1.jpg',
                                        'transparent' => get_template_directory_uri().'/assets/images/header/transparent.jpg',
                                        'layout2' => get_template_directory_uri().'/assets/images/header/layout2.jpg',
                                    )
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpwage'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
            'id'                => 'main_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/logo.png'
            ),
        ),
       
        array(
            'subtitle'          => esc_html__('Set max height for Header.', 'wpwage'),
            'id'                => 'header_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Header Height', 'wpwage'),
            'default'  => array(
                'height'  => '108px',
            ),
            /*'required'          => array('header_layout' ,'!=' ,'default'), */
        ),
        
        array(
            'title'             => esc_html__('Background', 'wpwage'),
            'subtitle'          => esc_html__('Header background.', 'wpwage'),
            'id'                => 'header_background',
            'type'              => 'background',
            'preview'           => false,
            'output'            => array( '#cshero-header' ),
        ),

        
        
        array(
            'id'                => 'header_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpwage' ),
            'subtitle'          => esc_html__( 'Select links color in header', 'wpwage' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => true,
            'visited'           => false,
            'output'            => array( '#cshero-header a,.widget_cart_search_wrap .header-icon' ),
            'default'  => array( 
                'hover'    => '#aaacb5', 
                'active'   => '#aaacb5',  
                'regular'   => '#fff',  
            ),
            /* 'required'          => array('header_layout' ,'!=' ,'layout1'),*/
        ),
        
        array(
            'subtitle'          => esc_html__('Enable mega menu.', 'wpwage'),
            'id'                => 'mega_menu',
            'type'              => 'switch',
            'title'             => esc_html__('Mega Menu', 'wpwage'),
            'default'           => true,
        ),
        array(
            'id'    => 'info_topbar',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Top Bar', 'wpwage'),
        ),
         array(
            'subtitle'          => esc_html__('Enable top bar.', 'wpwage'),
            'id'                => 'enable_top_bar',
            'type'              => 'switch',
            'title'             => esc_html__('Top Bar', 'wpwage'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Set max height for topbar.', 'wpwage'),
            'id'                => 'topbar_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Topbar Height', 'wpwage'),
            'default'  => array(
                'height'  => '50px',
            ),
            'required'          => array( 'enable_top_bar', '=', 1 )
        ),
          array(
            'id'                => 'topbar_text_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Top Text Color', 'wpwage' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '#cshero-header .topbar ul.top_bar ' ),
            'default'  => '#aaacb5',
             'required'          => array( 'enable_top_bar', '=', 1 )
        ),
          array(
            'id'                => 'topbar_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Top Links Color', 'wpwage' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '#cshero-header .topbar ul.top_bar li a' ),
            'default'  => array( 
                'hover'    => '#fff',   
                'regular'   => '#aaacb5',  
            ),
            'required'          => array( 'enable_top_bar', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Top Bar Background', 'wpwage'),
            'subtitle'          => esc_html__('Top Bar background.', 'wpwage'),
            'id'                => 'topbarbackground',
            'type'              => 'background',
            'output'            => array( '.topbar' ),
            'required'          => array( 'enable_top_bar', '=', 1 ),
        ),
        array(
            'subtitle'          => esc_html__('Add Info', 'wpwage'),
            'id'                => 'topbar_info',
            'type'              => 'text',
            'title'             => esc_html__('Info', 'wpwage'),
            'default'           => esc_html__('info&#64;wage.com', 'wpwage'),
            'required'          => array( 'enable_top_bar', '=', 1 )
        ),
        array(
            'subtitle'          => esc_html__('Add Phone Number', 'wpwage'),
            'id'                => 'topbar_phone',
            'type'              => 'text',
            'title'             => esc_html__('Phone', 'wpwage'),
            'default'           => esc_html__('+(00) 111-222-333', 'wpwage'),
            'required'          => array( 'enable_top_bar', '=', 1 )
        ),
        array(
            'subtitle'          => esc_html__('Add Time', 'wpwage'),
            'id'                => 'topbar_time',
            'type'              => 'text',
            'title'             => esc_html__('Time', 'wpwage'),
            'default'           => esc_html__('Mon-sat(10am-4pm)', 'wpwage'),
            'required'          => array( 'enable_top_bar', '=', 1 )
        ),
        array(
            'id'    => 'info_sticky',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Sticky', 'wpwage'),
        ),
        array(
            'subtitle'          => esc_html__('enable sticky mode for menu.', 'wpwage'),
            'id'                => 'menu_sticky',
            'type'              => 'switch',
            'title'             => esc_html__('Sticky Header', 'wpwage'),
            'default'           => true,
        ),
         array(
            'subtitle'          => esc_html__('Set max Header height .', 'wpwage'),
            'id'                => 'logo_max_height_sticky',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Header Height', 'wpwage'),
            'default'  => array(
                'height'  => '103px'
            ),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Logo Type', 'wpwage'),
            'subtitle'          => esc_html__('From Main / Image.', 'wpwage'),
            'id'                => 'sticky_logo_type',
            'type'              => 'button_set',
            'options'           => array(
                'default' => esc_html__('Main', 'wpwage'),
                'img' => esc_html__('Image', 'wpwage'),
            ),
            'default'           => 'img',
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpwage'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
            'id'                => 'sticky_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/logo.png'
            ),
             'required'          => array(
                    array( 'sticky_logo_type', '=', 'img' ),

                )
        ),
         array(
            'id'                => 'sticky_header_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpwage' ),
            'visited'           => false,
            'subtitle'          => esc_html__( 'Select links color in header', 'wpwage' ),
            'output'            => array( ' .hd-fixed  #cshero-header a' ),
            'default'  => array( 
                'hover'    => '#aaacb5', 
                'active'   => '#222',  
                'regular'   => '#222',  
            ),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'id'                => 'sticky_header_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Sticky Background Color', 'wpwage' ),
            'subtitle'          => esc_html__( 'Header Sticky  background color', 'wpwage' ),
            'default'   => array(
                'color'     => '#fff',
            ),
            'output' => array(
                'background-color' => '.hd-fixed  #cshero-header',
            ),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
    )
));
/*Option For Default */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Options Layout 1', 'wpwage'),
    'subsection' => 'true',
    'icon' => 'el-icon-credit-card',
    'fields' => array(
           array(
            'subtitle'          => esc_html__('Set max height for logo.', 'wpwage'),
            'id'                => 'logo_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Logo Height', 'wpwage'),
            'default'  => array(
                'height'  => '129px'
            ),
        ),
        array(
            'subtitle'          => esc_html__('Set max height for menu.', 'wpwage'),
            'id'                => 'menu_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Menu Height', 'wpwage'),
            'default'  => array(
                'height'  => '87px',
                ),
            ),
         array(
            'title'             => esc_html__('Background For Logo', 'wpwage'),
            'id'                => 'logo_background',
            'type'              => 'background',
            'preview'           => false,
            'background-image'  =>false,
            'background-position'  =>false,
            'background-attachment'  =>false,
            'background-repeat'  =>false,
            'background-size'  =>false,
            'output'            => array( '.default #cshero-header .main_logo' ),
            'default'  => array(
                    'background-color' => '#fff',
                )
        ),
        )
    ));
/*Option For Layout 1 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Options Layout 2', 'wpwage'),
    'subsection' => 'true',
    'icon' => 'el-icon-credit-card',
    'fields' => array(
            array(
                'id'                => 'header_link_color_layout1',
                'type'              => 'link_color',
                'title'             => esc_html__( 'Links Color', 'wpwage' ),
                'subtitle'          => esc_html__( 'Select links color in header', 'wpwage' ),
                'regular'           => true,
                'hover'             => true,
                'active'            => true,
                'visited'           => false,
                'output'            => array( '.layout1 #cshero-header a' ),
                'default'  => array( 
                    'hover'    => '#aaacb5', 
                    'active'   => '#aaacb5',  
                    'regular'   => '#222',  
                ),
            ),
            array(
                'id'                => 'layout1_topbar_link_color',
                'type'              => 'link_color',
                'title'             => esc_html__( 'Top Links Color', 'wpwage' ),
                'regular'           => true,
                'hover'             => true,
                'active'            => false,
                'visited'           => false,
                'output'            => array( '.layout1 #cshero-header .topbar ul.top_bar li a' ),
                'default'  => array( 
                    'hover'    => '#222',   
                    'regular'   => '#aaacb5',  
                ),
            ),
            array(
                'title'             => esc_html__('Background', 'wpwage'),
                'subtitle'          => esc_html__('Header background.', 'wpwage'),
                'id'                => 'header_background_layout1',
                'type'              => 'background',
                'preview'           => false,
                'output'            => array( '.layout1 #cshero-header' ),
                'default'  => array(
                        'background-color' => '#fff',
                    ),
            ),
             array(
                'id'                => 'layout1_header_boxed',
                'type'              => 'switch',
                'title'             => esc_html__('Header Boxed', 'wpwage'),
                'default'           => false,
            ),
        )
    ));

/*Option For Layout Transparent */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Options Layout 3', 'wpwage'),
    'subsection' => 'true',
    'icon' => 'el-icon-credit-card',
    'fields' => array(
             array(
                'title'             => esc_html__('Select Logo', 'wpwage'),
                'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
                'id'                => 'main_logo_transparent',
                'type'              => 'media',
                'url'               => true,
                'default'           => array(
                    'url'=>get_template_directory_uri().'/assets/images/logo-white.png'
                ),
            ),
        )
    ));

/*Option For Layout 2 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Options Layout 4', 'wpwage'),
    'subsection' => 'true',
    'icon' => 'el-icon-credit-card',
    'fields' => array(
            array(
                'title'             => esc_html__('Background', 'wpwage'),
                'subtitle'          => esc_html__('Header background.', 'wpwage'),
                'id'                => 'header_background_layout2',
                'type'              => 'background',
                'preview'           => false,
                'output'            => array( '.layout2 #cshero-header' ),
                'default'  => array(
                        'background-color' => '#222',
                    ),
            ),
             array(
            'title'             => esc_html__('Background For Logo', 'wpwage'),
            'id'                => 'logo_background_layout2',
            'type'              => 'background',
            'preview'           => false,
            'background-image'  =>false,
            'background-position'  =>false,
            'background-attachment'  =>false,
            'background-repeat'  =>false,
            'background-size'  =>false,
            'output'            => array( '.layout2 #cshero-header .main_logo' ),
            'required'          => array( 

             ),
            'default'  => array(
                    'background-color' => '#fff',
                )
        ),
        )
    ));
/**
 * Page Title
 *
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Page Title & BC', 'wpwage'),
    'icon' => 'el-icon-map-marker',
    'fields' => array(
        array(
            'id'                => 'page_title_layout',
            'title'             => esc_html__('Layouts', 'wpwage'),
            'subtitle'          => esc_html__('select a layout for page title', 'wpwage'),
            'default'           => 'default',
            'type'              => 'image_select',
            'options'           => array(
                                    'default' => get_template_directory_uri().'/assets/images/pagetitle.png',
                                )
        ),
        array(
            'title'             => esc_html__('Background', 'wpwage'),
            'subtitle'          => esc_html__('Page title background.', 'wpwage'),
            'id'                => 'page_title_background',
            'type'              => 'background',
            'output'            => array( '#page-title' ),
            'default'           => array(
                    'background-image' => get_template_directory_uri().'/assets/images/pagetitle.jpg',
                    'background-repeat'=> 'no-repeat',
                    'background-position'=> 'center top',
                    'background-size'=> 'cover',
                    'background-color'=> '#222',
                ),
        ),
        array(
            'id'                => 'pagetile_text_color_overlay',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background Overlay Color', 'wpwage' ),
            'subtitle'          => esc_html__( 'Select background color in pagetitle', 'wpwage' ),
            'default'   => array(
                    'color'     => '#222',
                    'alpha'     => 0.7
                ),
        ),
        array(
            'id'                => 'pagetile_text_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Text Color', 'wpwage' ),
            'subtitle'          => esc_html__( 'Select text color in pagetitle', 'wpwage' ),
            'default'  => '#25ae60',
        ),
        array(
            'id'                => 'pagetile_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpwage' ),
            'visited'           => false,
            'subtitle'          => esc_html__( 'Select links color in pagetitle', 'wpwage' ),
            'default'  => array( 
                'regular'    => '#aaacb5', 
                'hover'    => '#fff', 
                'active'    => '#fff', 
            )
        ),
        array(
            'title'             => esc_html__('Padding', 'wpwage'),
            'subtitle'          => esc_html__('Page title padding (top/bottom).', 'wpwage'),
            'id'                => 'page_title_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array( 'px'),
            'top'               => true,
            'right'             => false,
            'bottom'            => true,
            'left'              => false,
            'output'            => array( '#page-title' ),
            'default'            => array(
                'padding-top'     => '234px', 
                'padding-bottom'  => '45px', 
                'units'          => 'px', 
            )
        ),
    )
));

/**
 * Content
 *
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Content', 'wpwage'),
    'icon' => 'el-icon-pencil',
    'fields' => array(
    )
));

/* archive */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Archive', 'wpwage'),
    'icon' => 'el-icon-list',
    'subsection' => true,
    'fields' => array(
        array(
            'id'                => 'archive_layout',
            'title'             => esc_html__('Layouts', 'wpwage'),
            'subtitle'          => esc_html__('select a layout for archive, search, index...', 'wpwage'),
            'default'           => 'right',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/left.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/right.png',
                                    )
        ),
        array(
            'subtitle'          => esc_html__('Show author.', 'wpwage'),
            'id'                => 'archive_author',
            'type'              => 'switch',
            'title'             => esc_html__('Author', 'wpwage'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show tags.', 'wpwage'),
            'id'                => 'archive_tag',
            'type'              => 'switch',
            'title'             => esc_html__('Tags', 'wpwage'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show comment count.', 'wpwage'),
            'id'                => 'archive_comment',
            'type'              => 'switch',
            'title'             => esc_html__('Comment', 'wpwage'),
            'default'           => true,
        ),
    )
));

/* Single */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single', 'wpwage'),
    'icon' => 'el-icon-file-edit',
    'subsection' => true,
    'fields' => array(
        array(
            'id'                => 'single_layout',
            'title'             => esc_html__('Layouts', 'wpwage'),
            'subtitle'          => esc_html__('select a layout for single...', 'wpwage'),
            'default'           => 'right',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/left.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/right.png',
                                    )
        ),
        array(
            'subtitle'          => esc_html__('Show author.', 'wpwage'),
            'id'                => 'single_author',
            'type'              => 'switch',
            'title'             => esc_html__('Author', 'wpwage'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show comment count.', 'wpwage'),
            'id'                => 'single_comment',
            'type'              => 'switch',
            'title'             => esc_html__('Comment', 'wpwage'),
            'default'           => true,
        ),
    )
));

/**
 * Styling
 * 
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Styling', 'wpwage'),
    'icon' => 'el-icon-adjust',
    'fields' => array(
        array(
            'subtitle' => esc_html__('Set color main color.', 'wpwage'),
            'id' => 'primary_color',
            'type' => 'color',
            'title' => esc_html__('Primary Color', 'wpwage'),
            'default' => '#25ae60'
        ),
        array(
            'subtitle' => esc_html__('Set color secondary color.', 'wpwage'),
            'id' => 'secondary_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'wpwage'),
            'default' => '#131f58'
        ),
        array(
            'id'       => 'link_color',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Links Color', 'wpwage' ),
            'subtitle' => esc_html__( 'Select Links Color Option', 'wpwage' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'output'   => array( 'a' ),
            'default'  => array(
                'regular' => '#222',
                'hover'   => '#01ce83', 
            ),
        ),

        array(
            'subtitle' => esc_html__('Set color link secondary color.', 'wpwage'),
            'id' => 'link_secondary_color',
            'type' => 'color',
            'title' => esc_html__('Link Secondary Color', 'wpwage'),
            'default' => '#aaacb5'
        ),
        array(
            'subtitle' => esc_html__('Set color link color three.', 'wpwage'),
            'id' => 'link_color_three',
            'type' => 'color',
            'title' => esc_html__('Link Color Three', 'wpwage'),
            'default' => '#53545a'
        ),
    )
));

/**
 * Typography
 * 
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Typography', 'wpwage'),
    'icon' => 'el-icon-text-width',
    'fields' => array(
        array(
            'id' => 'font_body',
            'type' => 'typography',
            'title' => esc_html__('Body Font', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('body'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage'),
             'default' => array(
                'color' => '#8f8f8f',
                'font-style' => '',
                'font-weight' => '400',
                'font-family' => 'Source Sans Pro',
                'google' => true,
                'font-size' => '16px',
                'line-height' => '24px',
                'text-align' => '',
                'font-backup'   => 'Arial, Helvetica, sans-serif',
            )
            
        ),
        array(
            'id' => 'font_h1',
            'type' => 'typography',
            'title' => esc_html__('H1', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h1'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        ),
        array(
            'id' => 'font_h2',
            'type' => 'typography',
            'title' => esc_html__('H2', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h2'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        ),
        array(
            'id' => 'font_h3',
            'type' => 'typography',
            'title' => esc_html__('H3', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h3'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        ),
        array(
            'id' => 'font_h4',
            'type' => 'typography',
            'title' => esc_html__('H4', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h4'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        ),
        array(
            'id' => 'font_h5',
            'type' => 'typography',
            'title' => esc_html__('H5', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h5'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        ),
        array(
            'id' => 'font_h6',
            'type' => 'typography',
            'title' => esc_html__('H6', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('h6'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage')
        )
    )
));

/* extra font. */
$custom_font_1 = Redux::getOption($opt_name, 'google-font-selector-1');
$custom_font_1 = !empty($custom_font_1) ? explode(',', $custom_font_1) : array();

Redux::setSection($opt_name, array(
    'title' => esc_html__('Extra Fonts', 'wpwage'),
    'icon' => 'el el-fontsize',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'google-font-1',
            'type' => 'typography',
            'title' => esc_html__('Custom Font', 'wpwage'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  =>  $custom_font_1,
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpwage'),
            'default' => array(
                'color' => '',
                'font-style' => '',
                'font-weight' => '',
                'font-family' => '',
                'google' => true,
                'font-size' => '',
                'line-height' => '',
                'text-align' => ''
            )
        ),
        array(
            'id' => 'google-font-selector-1',
            'type' => 'textarea',
            'title' => esc_html__('Selector 1', 'wpwage'),
            'subtitle' => esc_html__('add html tags ID or class (body,a,.class,#id)', 'wpwage'),
            'validate' => 'no_html',
            'default' => '',
        )
    )
));

/**
 * Woocommerce
 * 
 * Optimal options for theme. optimal speed
 * @author DieuLinh
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Woocommerce', 'wpwage'),
    'icon' => 'el el-shopping-cart',
    'fields' => array(
        array(
            'subtitle' => 'Shop List Sidebar Left, Shop List Sidebar Right, Full Width',
            'id' => 'woo_layout',
            'type' => 'image_select',
            'default' => 'left-sidebar',
            'options' => array(
                'full-width' => get_template_directory_uri().'/assets/images/1col.png',
                'right-sidebar' => get_template_directory_uri().'/assets/images/2cr.png',
                'left-sidebar' => get_template_directory_uri().'/assets/images/2cl.png'
            ),
            'title' => esc_html__('Shop Layout', 'wpwage'),
        ),
        array(
            'id'       => 'woo_column',
            'type'     => 'select',
            'title'    => esc_html__('Select Column', 'wpwage'), 
            'options'  => array(
                '2' => '2',
                '3' => '3',
                '4' => '4'
            ),
            'default'  => '3',
        ),
        array(
            'id' => 'woo_item_per_page',
            'type' => 'slider',
            'title' => esc_html__('Select Item Page', 'wpwage'),
            "default" => 9,
            "min" => 0,
            "step" => 1,
            "max" => 30,
            'display_value' => 'text'
        ),
 
    )
));

/**
 * Footer
 *
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer', 'wpwage'),
    'icon' => 'el el-website',
    'fields' => array(
        array(
            'id'    => 'info_footer_top',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Footer Top', 'wpwage'),
        ),
        array(
            'id'                => 'show_footer_top',
            'type'              => 'switch',
            'title'             => esc_html__('Show Footer Top', 'wpwage'),
            'default'           => true,
        ),
        array(
            'id'       => 'footer-top-column',
            'type'     => 'select',
            'title'    => esc_html__( 'Column', 'wpwage' ),
            'subtitle' => esc_html__( 'Select Footer Column', 'wpwage' ),
            'default'    => 4,
            'options'  => array(
                1 => esc_html__('1', 'wpwage' ),
                2 => esc_html__('2', 'wpwage' ),
                3 => esc_html__('3', 'wpwage' ),
                4 => esc_html__('4', 'wpwage' ),
            ),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpwage'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
            'id'                => 'footerlogo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-footer.png'
            ),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Background Color', 'wpwage'),
            'subtitle'          => esc_html__('Footer top background color.', 'wpwage'),
            'id'                => 'footer_top_background',
            'type'              => 'color_rgba',
            'output'            => array( 'background-color' => 'footer #footer-top', ),
            'default'           => array(
                                    'color'     => '#222',
                                    'alpha'     => 1
                                ),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Background Image', 'wpwage'),
            'subtitle'          => esc_html__('Footer top background image.', 'wpwage'),
            'id'                => 'footer_top_background_image',
            'type'              => 'background',
            'background-color'  => false,
            'output'            => array( 'footer #footer-top', ),
            /*'default'           => array(
               'background-image' => get_template_directory_uri().'/assets/images/bgfooter.jpg'
                                ),*/
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Background Color Overlay', 'wpwage'),
            'id'                => 'footer_top_background_overlay',
            'type'              => 'checkbox',
            'default'  => '0',
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Background Color Col 1', 'wpwage'),
            'id'                => 'footer_top_background_color_col1',
            'type'              => 'color_rgba',
            'output'            => array( 'background-color' => 'footer .footer-top-1-wrap .footer-top-1-inner:before ', ),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title' => esc_html__('Heading Color', 'wpwage'),
            'id' => 'footer_heading_color',
            'type' => 'color',
            'default' => '#fff',
            'output' => array('footer #footer-top h3.wg-title'),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title' => esc_html__('Text Color', 'wpwage'),
            'id' => 'footer_top_text_color',
            'type' => 'color',
            'default' => '#5d5d5d',
            'output' => array('footer #footer-top'),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),
        array(
            'title' => esc_html__('Footer Top link color', 'wpwage'),
            'subtitle' => esc_html__('Set footer top link color.', 'wpwage'),
            'id' => 'footer_top_link_color',
            'type' => 'link_color',
            'visited' => false,
            'output' => array('footer #footer-top a'),
            'default' => array(
                'regular'  => '#5d5d5d',
                'hover'    => '#8f8f8f',
                'active'    => '#e7e7e7',
            ),
            'required'          => array( 'show_footer_top', '=', 1 )
        ),

         
        array(
            'title'             => esc_html__('Padding', 'wpwage'),
            'subtitle'          => esc_html__('Footer top padding (top/bottom).', 'wpwage'),
            'id'                => 'footer_top_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array('px'),
            'right'             => false,
            'left'              => false,
            'output'            => array( 'footer #footer-top' ),
            'default'            => array(
                'padding-top'     => '50px', 
                'padding-bottom'  => '40px', 
                'units'          => 'px', 
            ),
            'required'          => array( 'show_footer_top', '=', 1 )

        ),
        array(
            'id'    => 'info_footer_bottom',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Footer Bottom', 'wpwage'),
        ),
        array(
            'id'                => 'show_footer_bottom',
            'type'              => 'switch',
            'title'             => esc_html__('Show Footer Bottom', 'wpwage'),
            'default'           => true,
        ),
        array(
            'title'             => esc_html__('Background', 'wpwage'),
            'subtitle'          => esc_html__('Footer top background.', 'wpwage'),
            'id'                => 'footer_bottom_background',
            'type'              => 'background',
            'output'            => array( 'footer #footer-bottom' ),
            'default'           => array(
                                    'background-color' => '#131313',
                                ),
            'required'          => array( 'show_footer_bottom', '=', 1 )
        ),
        array(
            'title' => esc_html__('Text Color', 'wpwage'),
            'id' => 'footer_bottom_text_color',
            'type' => 'color',
            'default' => '#4f4e4e',
            'output' => array('footer #footer-bottom'),
            'required'          => array( 'show_footer_bottom', '=', 1 )
        ),
        array(
            'id'                => 'footer_bottom_social_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Social Color', 'wpwage' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( ' #footer-bottom .social_footer a' ),
            'default'           => array(
                'regular'       => '#4f4e4e',
                'hover'         => '#fff',
            ),
             'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'title'             => esc_html__('Padding', 'wpwage'),
            'subtitle'          => esc_html__('Footer bottom padding (top/bottom).', 'wpwage'),
            'id'                => 'footer_bottom_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array('px'),
            'right'             => false,
            'left'              => false,
            'output'            => array( 'footer #footer-bottom' ),
            'default'            => array(
                'padding-top'     => '40px', 
                'padding-bottom'  => '40px', 
                'units'          => 'px', 
            ),
            'required'          => array( 'show_footer_bottom', '=', 1 )
        ),
         array(
            'subtitle'          => esc_html__('Add custom copyright Text.', 'wpwage'),
            'id'                => 'copyright_footer',
            'type'              => 'textarea',
            'title'             => esc_html__('Copyright', 'wpwage'),
            'default'           => esc_html__('Copyright &#169; 2017 All Rights Reserved by RedExp.', 'wpwage'),
            'required'          => array( 'show_footer_bottom', '=', 1 )
         ),

        array(
            'subtitle'          => esc_html__('Enable back to top button.', 'wpwage'),
            'id'                => 'general_back_to_top',
            'type'              => 'switch',
            'title'             => esc_html__('Back To Top', 'wpwage'),
            'default'           => true,
        )
    )
));
/**
 * Social Footer Bottom Options
 * 
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Social', 'wpwage'),
    'icon' => 'el-icon-rss ',
    'fields' => array(
         array(
            'subtitle'          => esc_html__('Enable social.', 'wpwage'),
            'id'                => 'enable_social_footer_bottom',
            'type'              => 'switch',
            'title'             => esc_html__('Social', 'wpwage'),
            'default'           => true,
        ),
        array(
            'id'    => 'facebook-fb',
            'type'  => 'text',
            'title' => esc_html__('Facebook Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'twitter-fb',
            'type'  => 'text',
            'title' => esc_html__('Twitter Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'instagram-fb',
            'type'  => 'text',
            'title' => esc_html__('Instagram Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'pinterest-fb',
            'type'  => 'text',
            'title' => esc_html__('Pinterest Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'dribbble-fb',
            'type'  => 'text',
            'title' => esc_html__('Dribbble Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'google-fb',
            'type'  => 'text',
            'title' => esc_html__('Google Plus Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ), 
        array(
            'id'    => 'youtube-fb',
            'type'  => 'text',
            'title' => esc_html__('Youtube Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'linkedin-fb',
            'type'  => 'text',
            'title' => esc_html__('Linkedin Url', 'wpwage'),
            'default' => '#',
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'    => 'individual_social_on_topbar_info',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('List social will show', 'wpwage'),
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
        array(
            'id'      => 'individual_social_on_footer_bottom',
            'type'    => 'sorter',
            'title'   => 'Socials',
            'options' => array(
                'enabled'  => array(
                    'facebook-fb' => esc_html__('Facebook', 'wpwage'),
                    'twitter-fb'  => esc_html__('Twitter', 'wpwage'),
                    'instagram-fb' => esc_html__('Youtube', 'wpwage'),
                    'pinterest-fb' => esc_html__('Pinterest', 'wpwage'),
                    'dribbble-fb' => esc_html__('Dribbble', 'wpwage'),
                    'google-fb' => esc_html__('Google', 'wpwage'),
                ),
                'disabled' => array(
                    'youtube-fb' => esc_html__('Youtube', 'wpwage'),
                    'linkedin-fb' => esc_html__('Linkedin', 'wpwage'),
                )
            ),
            'required'          => array( 'enable_social_footer_bottom', '=', 1 ),
        ),
    )
));
/**
 * 404
 * 
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('404', 'wpwage'),
    'icon' => 'el-icon-qrcode',
    'fields' => array(
        array(
            'id'    => 'info-error',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Error 404', 'wpwage'),
        ),
         
         
        array(
            'id' => 'error_title_color',
            'type' => 'color',
            'title' => esc_html__('Titlte Color', 'wpwage'),
            'default' => '#aaacb5',
            'output'            => array( '.error404 .error-page-inner .title' ),
        ), 
        array(
            'id' => 'error_text_color',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'wpwage'),
            'default' => '#fff',
            'output'            => array( '.error404 .error-page-inner .desc' ),
        ),
       array(
            'title'             => esc_html__('Background', 'wpwage'),
            'id'                => 'error_background',
            'type'              => 'background',
            'output'            => array( 'body.error404 ' ),
            'default'           => array(
                'background-color' => '#fff',
                'background-image' => get_template_directory_uri().'/assets/images/404.jpg',
                'background-repeat'=> 'no-repeat',
                'background-position'=> 'center top',
                'background-size'=> 'inherit',
            ),
        ),
       array(
            'id' => 'error_overlay',
            'type' => 'color_rgba',
            'title' => esc_html__('Background Overlay Color', 'wpwage'),
            'default'           => array(
                                    'color'     => '#222',
                                    'alpha'     => 0.6
                                ),
        ),
    )
));
/**
 * Coming Soon
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Coming Soon', 'wpwage'),
    'icon' => 'el el-error',
    'fields' => array(
        array(
            'title'             => esc_html__('Body Background', 'wpwage'),
            'subtitle'          => esc_html__('Body background.', 'wpwage'),
            'id'                => 'comingsoon-bg',
            'type'              => 'background',
            'output'            => array( '.page-template-comingsoon' ),
            'default' =>array(
                'background-image' => get_template_directory_uri().'/assets/images/404.jpg',
                'background-repeat' => 'no-repeat',
                'background-position' => 'center top',
                'background-size' => 'cover',
                'background-attachment' => ''
            ),
        ),

        array(
            'id' => 'comming_overlay',
            'type' => 'color_rgba',
            'title' => esc_html__('Background Overlay Color', 'wpwage'),
            'default'           => array(
                    'color'     => '#222',
                    'alpha'     => 0.6
                ),
        ),
    )
));

/**
 * Maintenance Mode
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Maintenance Mode.', 'wpwage'),
    'icon' => 'el el-wrench',
    'fields' => array(
        array(
            'title'             => esc_html__('Body Background', 'wpwage'),
            'subtitle'          => esc_html__('Body background.', 'wpwage'),
            'id'                => 'maintenance-bg',
            'type'              => 'background',
            'output'            => array( '.page-template-maintenance' ),
            'default' =>array(
                'background-image' => get_template_directory_uri().'/assets/images/404.jpg',
                'background-repeat' => 'no-repeat',
                'background-position' => 'center top',
                'background-size' => 'cover',
                'background-attachment' => ''
            ),
        ),

        array(
            'id' => 'maintenance_overlay',
            'type' => 'color_rgba',
            'title' => esc_html__('Background Overlay Color', 'wpwage'),
            'default'           => array(
                    'color'     => '#222',
                    'alpha'     => 0.6
                ),
        ),
    )
));
/**
 * Optimal Core
 * 
 * Optimal options for theme. optimal speed
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Optimal Core', 'wpwage'),
    'icon' => 'el-icon-idea',
    'fields' => array(
        array(
            'subtitle' => esc_html__('no minimize , generate css over time...', 'wpwage'),
            'id' => 'dev_mode',
            'type' => 'switch',
            'title' => esc_html__('Dev Mode (not recommended)', 'wpwage'),
            'default' => false
        )
    )
));