<?php
/**
 * Meta box config file
 */
if (! class_exists('MetaFramework')) {
    return;
}

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => apply_filters('opt_meta', 'opt_meta_options'),
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Allow you to start the panel in an expanded way initially.
    'open_expanded' => false,
    // Disable the save warning when a user changes a field
    'disable_save_warn' => true,
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => false,

    'output' => false,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // 'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
    'admin_bar' => false,
    // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => false,
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => false,
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => false,
    // save meta to multiple keys.
    'meta_mode' => 'multiple'
);

// -> Set Option To Panel.
MetaFramework::setArgs($args);

add_action('admin_init', 'wage_meta_boxs');

MetaFramework::init();

function wage_meta_boxs()
{

    /** page options */
    MetaFramework::setMetabox(array(
        'id' => '_page_main_options',
        'label' => esc_html__('Page Setting', 'wpwage'),
        'post_type' => 'page',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => false,
        'sections' => array(
             array(
                'title' => esc_html__('General', 'wpwage'),
                'id' => 'tab-general',
                'icon' => 'el el-adjust-alt',
                'fields' => array(
                    array(
                        'id' => 'page_general_space_body',
                        'title' => esc_html__('Space Body is 70px', 'wpwage'),
                        'type' => 'info',
                        'style' => 'success',
                    ),
                    array(
                        'id' => 'page_space_body',
                        'default' => '',
                        'type' => 'switch',
                        'default' => false,
                        'title' => esc_html__('Show Space Around Body', 'wpwage'),
                    ),
                    array(
                        'id' => 'page_general_padding',
                        'title' => esc_html__('At moment, main content got padding top and bottom is 60px', 'wpwage'),
                        'type' => 'info',
                        'style' => 'success',
                    ),
                    array(
                        'id' => 'page_general_padding_top',
                        'title' => esc_html__('Set padding top to 0px', 'wpwage'),
                        'desc' => esc_html__('Enable this option to set padding top of main content is 0px ', 'wpwage'),
                        'default' => '',
                        'type' => 'switch',
                        'default' => false,
                    ),
                    array(
                        'id' => 'page_general_padding_bottom',
                        'title' => esc_html__('Set padding bottom to 0px', 'wpwage'),
                        'desc' => esc_html__('Enable this option to set padding bottom of main content is 0px ', 'wpwage'),
                        'default' => '',
                        'type' => 'switch',
                        'default' => false,
                    ),
                    array(
                        'title' => esc_html__('Content background color', 'wpwage'),
                        'subtitle' => esc_html__('Set background color for content page, default - inherit from theme option', 'wpwage'),
                        'id' => 'page_general_color',
                        'type' => 'color',
                        'default' => '',
                    ),

                ),
            ),
            array(
                'title' => esc_html__('Header', 'wpwage'),
                'id' => 'tab-page-header',
                'icon' => 'el el-credit-card',
                'fields' => array(
                   array(
                        'id'                => 'header_layout',
                        'title'             => esc_html__('Layouts', 'wpwage'),
                        'subtitle'          => esc_html__('select a layout for header', 'wpwage'),
                        'default'           => 'inherit',
                        'type'              => 'image_select',
                        'options'           => array(
                                    'inherit' => get_template_directory_uri().'/assets/images/header/inherit.jpg',
                                    'default' => get_template_directory_uri().'/assets/images/header/default.jpg',
                                    'layout1' => get_template_directory_uri().'/assets/images/header/layout1.jpg',
                                    'transparent' => get_template_directory_uri().'/assets/images/header/transparent.jpg',
                                    'layout2' => get_template_directory_uri().'/assets/images/header/layout2.jpg',
                                    'fullscreenmenu' => get_template_directory_uri().'/assets/images/header/fullscreen-menu.jpg',
                                ),
                    ),
                     array(
                            'id'                => 'layout1_header_boxed',
                            'type'              => 'button_set',
                            'title'             => esc_html__('Header Boxed', 'wpwage'),
                            'required'          => array('header_layout' ,'=' ,'layout1'), 
                             'options' => array(
                                    'inherit' => 'Inherit', 
                                    '1' => 'Enable', 
                                    '0' => 'Disable'
                                 ), 
                                'default' => 'inherit'
                        ),
                   array(
                        'title'             => esc_html__('Select Logo', 'wpwage'),
                        'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
                        'id'                => 'full_logo',
                        'type'              => 'media',
                        'url'               => true,
                        'required'          => array( 'header_layout', '=', 'fullscreenmenu' )
                    ),
                   array(
                        'title'             => esc_html__('Select Logo Sticky', 'wpwage'),
                        'subtitle'          => esc_html__('Select an image file for your logo.', 'wpwage'),
                        'id'                => 'full_logo_sticky',
                        'type'              => 'media',
                        'url'               => true,
                        'required'          => array( 'header_layout', '=', 'fullscreenmenu' )
                    ),
                    array(
                        'title' => esc_html__('Link color', 'wpwage'),
                        'id' => 'item_link_color_fullscreen',
                        'type' => 'link_color',
                        'visited' => false,
                        'default' => array(
                            'regular'  => '#fff',
                            'hover'    => '#222',
                            'active'    => '#222',
                        ),
                       'required'          => array( 'header_layout', '=', 'fullscreenmenu' )
                    ),
                    array(
                        'subtitle'          => esc_html__('Set max height for menu.', 'wpwage'),
                        'id'                => 'fullmenu_max_height',
                        'type'              => 'dimensions',
                        'units'             => array('px'),
                        'width'             => false,
                        'title'             => esc_html__('Menu Height', 'wpwage'),
                        'default'  => array(
                            'height'  => '129px',
                            ),
                        'required'          => array( 'header_layout', '=', 'fullscreenmenu' )
                    ),
                    array(
                        'subtitle'          => esc_html__('Set max sticky height for menu.', 'wpwage'),
                        'id'                => 'fullmenu_max_height_sticky',
                        'type'              => 'dimensions',
                        'units'             => array('px'),
                        'width'             => false,
                        'title'             => esc_html__('Menu Height', 'wpwage'),
                        'default'  => array(
                            'height'  => '87px',
                            ),
                        'required'          => array( 'header_layout', '=', 'fullscreenmenu' )
                    ),
                    array(
                        'id' => 'header_menu',
                        'type' => 'select',
                        'title' => esc_html__('Select Menu', 'wpwage'),
                        'subtitle' => esc_html__('custom menu for current page', 'wpwage'),
                        'options' => wage_get_nav_menu(),
                        'default' => '',
                    ),
                    array(
                        'id'    => 'info-revslider',
                        'type'  => 'info',
                        'style' => 'success',
                        'title' => esc_html__('Rev Slider Option', 'wpwage'),
                        'required'          => array('header_layout' ,'=' ,'layout1'), 
                    ),
                    array(
                        'id'       => 'rev_slider_show',
                        'type'     => 'switch', 
                        'title'    => esc_html__( 'Rev Slider On Header', 'wpwage' ),
                        'default'  => false,
                        'required'          => array('header_layout' ,'=' ,'layout1'), 
                    ),

                    /*array(
                        'subtitle'          => esc_html__('Set max height for menu.', 'wpwage'),
                        'id'                => 'underslider_max_height',
                        'type'              => 'dimensions',
                        'units'             => array('px'),
                        'width'             => false,
                        'title'             => esc_html__('Menu Height', 'wpwage'),
                        'default'  => array(
                            'height'  => '123px',
                            ),
                        'required' => array('rev_slider_show', '=', true)
                    ),
                    array(
                        'subtitle'          => esc_html__('Set max sticky height for menu.', 'wpwage'),
                        'id'                => 'underslider_max_height_sticky',
                        'type'              => 'dimensions',
                        'units'             => array('px'),
                        'width'             => false,
                        'title'             => esc_html__('Menu Height', 'wpwage'),
                        'default'  => array(
                            'height'  => '103px',
                            ),
                        'required' => array('rev_slider_show', '=', true)
                    ),*/
                    array(
                        'id'       => 'select_rev_slider',
                        'type'     => 'select',
                        'title'    => esc_html__('Select Rev Slider', 'wpwage' ), 
                        'options'  =>  wage_get_list_rev_slider(),
                        'required' => array('rev_slider_show', '=', true)
                    ),
                    array(
                        'id'       => 'off_top_bar',
                        'type'     => 'switch', 
                        'title'    => esc_html__( 'Off Top Bar', 'wpwage' ),
                        'default'  => false,
                        'required'          => array('header_layout' ,'=' ,'layout1'), 
                    ),
                )
            ),
           array(
                'title' => esc_html__('Page Title & BC', 'wpwage'),
                'id' => 'tab-page-title-bc',
                'icon' => 'el el-map-marker',
                'fields' => array(
                    array(
                        'id'       => 'button_set_pagetitle',
                        'type'     => 'switch',
                        'title'    => esc_html__('Disable', 'wpwage'),
                        'default' => false,
                    ),
                    array(
                        'id' => 'page_title_text',
                        'type' => 'text',
                        'title' => esc_html__('Custom Title', 'wpwage'),
                        'subtitle' => esc_html__('Custom current page title.', 'wpwage'),
                    )
                )
            ),
            array(
                'title' => esc_html__('One Page', 'wpwage'),
                'id' => 'tab-one-page',
                'icon' => 'el el-download-alt',
                'fields' => array(
                    array(
                        'subtitle' => esc_html__('Enable one page mode for current page.', 'wpwage'),
                        'id' => 'page_one_page',
                        'type' => 'switch',
                        'title' => esc_html__('Enable', 'wpwage'),
                        'default' => false,
                    ),
                    array(
                        'id'            => 'page_one_page_speed',
                        'type'          => 'slider',
                        'title'         => esc_attr__( 'Speed', 'wpwage' ),
                        'default'       => 1000,
                        'min'           => 500,
                        'step'          => 100,
                        'max'           => 5000,
                        'display_value' => 'text',
                        'required' => array('page_one_page', '=', 1)
                    ),
                )
            ),
             array(
                'title' => esc_html__('Footer Style', 'wpwage'),
                'id' => 'tab-footer-top',
                'icon' => 'el el-website',
                'fields' => array(
                    array(
                        'id'    => 'info_footer_top',
                        'type'  => 'info',
                        'style' => 'success',
                        'title' => esc_html__('Footer Top', 'wpwage'),
                    ),
                    array(
                        'id'                => 'show_footer_top',
                        'type'              => 'button_set',
                        'title'             => esc_html__('Show Footer Top', 'wpwage'),
                        'options' => array(
                                    'inherit' => 'Inherit', 
                                    '1' => 'Custom', 
                                    '2' => 'Disable'
                                 ), 
                                'default' => 'inherit'
                    ),
                   
                     array(
                        'title'             => esc_html__('Background Color', 'wpwage'),
                        'subtitle'          => esc_html__('Footer top background color.', 'wpwage'),
                        'id'                => 'footer_top_background',
                        'type'              => 'color_rgba',
                        'required'          => array( 'show_footer_top', '=', '1' )
                    ),
                    array(
                        'title'             => esc_html__('Background Image', 'wpwage'),
                        'subtitle'          => esc_html__('Footer top background image.', 'wpwage'),
                        'id'                => 'footer_top_background_image',
                        'type'              => 'background',
                        'background-color'  => false,
                        /*'output'            => array( 'footer #footer-top', ),*/
                        /*'default'           => array(
                           'background-image' => get_template_directory_uri().'/assets/images/bgfooter.jpg'
                                            ),*/
                        'required'          => array( 'show_footer_top', '=', '1' )
                    ),
                    array(
                        'title'             => esc_html__('Background Color Overlay', 'wpwage'),
                        'id'                => 'footer_top_background_overlay',
                        'type'              => 'checkbox',
                        'default'  => '0',
                        'required'          => array( 'show_footer_top', '=', '1' )
                    ),
                    array(
                        'title'             => esc_html__('Background Color Col 1', 'wpwage'),
                        'id'                => 'footer_top_background_color_col1',
                        'type'              => 'color_rgba',
                        'output'            => array( 'background-color' => 'footer .footer-top-1-wrap .footer-top-1-inner:before ', ),
                        'required'          => array( 'show_footer_top', '=', "1" )
                    ),
                )
            )
        )
    ));

    /** post options */
    MetaFramework::setMetabox(array(
        'id' => '_page_post_format_options',
        'label' => esc_html__('Post Format', 'wpwage'),
        'post_type' => 'post',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'color-Color',
                'icon' => 'el el-laptop',
                'fields' => array(
                    array(
                        'id' => 'opt-video-type',
                        'type' => 'select',
                        'title' => esc_html__('Select Video Type', 'wpwage'),
                        'subtitle' => esc_html__('Local video, Youtube, Vimeo', 'wpwage'),
                        'options' => array(
                            'local' => esc_html__('Upload', 'wpwage'),
                            'youtube' => esc_html__('Youtube', 'wpwage'),
                            'vimeo' => esc_html__('Vimeo', 'wpwage'),
                        )
                    ),
                    array(
                        'id' => 'otp-video-local',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Local Video', 'wpwage'),
                        'subtitle' => esc_html__('Upload video media using the WordPress native uploader', 'wpwage'),
                        'required' => array('opt-video-type', '=', 'local')
                    ),
                    array(
                        'id' => 'opt-video-youtube',
                        'type' => 'text',
                        'title' => esc_html__('Youtube', 'wpwage'),
                        'subtitle' => esc_html__('Load video from Youtube.', 'wpwage'),
                        'placeholder' => esc_html__('https://youtu.be/iNJdPyoqt8U', 'wpwage'),
                        'required' => array('opt-video-type', '=', 'youtube')
                    ),
                    array(
                        'id' => 'opt-video-vimeo',
                        'type' => 'text',
                        'title' => esc_html__('Vimeo', 'wpwage'),
                        'subtitle' => esc_html__('Load video from Vimeo.', 'wpwage'),
                        'placeholder' => esc_html__('https://vimeo.com/155673893', 'wpwage'),
                        'required' => array('opt-video-type', '=', 'vimeo')
                    ),
                    array(
                        'id' => 'otp-video-thumb',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Video Thumb', 'wpwage'),
                        'subtitle' => esc_html__('Upload thumb media using the WordPress native uploader', 'wpwage'),
                        'required' => array('opt-video-type', '=', 'local')
                    ),
                    array(
                        'id' => 'otp-audio',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Audio Media', 'wpwage'),
                        'subtitle' => esc_html__('Upload audio media using the WordPress native uploader', 'wpwage'),
                    ),
                    array(
                        'id' => 'opt-gallery',
                        'type' => 'gallery',
                        'title' => esc_html__('Add/Edit Gallery', 'wpwage'),
                        'subtitle' => esc_html__('Create a new Gallery by selecting existing or uploading new images using the WordPress native uploader', 'wpwage'),
                    ),
                    array(
                        'id' => 'opt-quote-title',
                        'type' => 'text',
                        'title' => esc_html__('Quote Title', 'wpwage'),
                        'subtitle' => esc_html__('Quote title or quote name...', 'wpwage'),
                    ),
                    array(
                        'id' => 'opt-quote-content',
                        'type' => 'textarea',
                        'title' => esc_html__('Quote Content', 'wpwage'),
                    ),
                )
            ),
        )
    ));

/** Testimonial options */
    MetaFramework::setMetabox(array(
        'id' => '_page_testimonial_options',
        'label' => esc_html__('Testimonial Options', 'wpwage'),
        'post_type' => 'testimonials',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'social-testi-option',
                'icon' => 'el el-share-alt',
                'fields' => array(
                    array(
                        'id'    => 'role_testi',
                        'type'  => 'text',
                        'title' => esc_html__('Role', 'wpwage'),
                        'default' => '',
                    ),
                )
            ),
        )
    ));

    /** Services options */
    MetaFramework::setMetabox(array(
        'id' => '_page_services_options',
        'label' => esc_html__('Services Options', 'wpwage'),
        'post_type' => 'services',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'servives-custom-text-option',
                'icon' => 'el el-share-alt',
                'fields' => array(
                    array(
                        'id'    => 'services-excerpt',
                        'type'  => 'textarea',
                        'title' => esc_html__('Excerpt Services', 'wpwage'),
                        'default' => '',
                    ),
                )
            ),
        )
    ));
       /** Team options */
    MetaFramework::setMetabox(array(
        'id' => '_page_team_options',
        'label' => esc_html__('Team Options', 'wpwage'),
        'post_type' => 'team',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'social-team-option',
                'icon' => 'el el-share-alt',
                'fields' => array(
                    array(
                        'id'    => 'role_team',
                        'type'  => 'text',
                        'title' => esc_html__('Role', 'wpwage'),
                    ),
                   array(
                        'id'    => 'face_url_team',
                        'type'  => 'text',
                        'title' => esc_html__('Facebook Url', 'wpwage'),
                        'default' => '#',
                    ),
                   array(
                        'id'    => 'twitter_url_team',
                        'type'  => 'text',
                        'title' => esc_html__('Twitter Url', 'wpwage'),
                        'default' => '#',
                    ),
                    array(
                        'id'    => 'instagram_url_team',
                        'type'  => 'text',
                        'title' => esc_html__('Instagram Url', 'wpwage'),
                        'default' => '#',
                    ),
                    
                    
                )
            ),
        )
    ));
}