<?php defined( 'ABSPATH' ) or exit();
/**
 * Simple About Widget
 * This widget allows you to pick images, parse some text and show at the front-end.
 *
 * @author Stev Ngo <http://stevngodesign.com/>
 * @version 1.0
 */

class Cms_Brochures_Widget extends WP_Widget {
    /**
     * Constructor
     *
     * @return void
     **/
    function __construct() {
        parent::__construct(
            'cms_brochures', // Base ID
            esc_html__( 'Brochures', 'wpwage' ), // Name
            array(
                'description' => esc_html__( 'Add brochures box.', 'wpwage' ),
                'customize_selective_refresh' => true
            ) // Args
        );
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts') );
    }

    /**
     * Enqueue admin scripts and styles
     *
     * @return void
     */
    function admin_scripts() {
        wp_enqueue_style( 'wage-widgets', get_template_directory_uri() . '/inc/widgets/css/widgets.css' );
        wp_enqueue_media();
        wp_enqueue_script( 'wage-widgets', get_template_directory_uri() . '/inc/widgets/js/widgets.js', array( 'jquery', 'media-upload' ), '', true );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array  An array of standard parameters for widgets in this theme
     * @param array  An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance )
    {
        extract( $args, EXTR_SKIP );
        
        $instance = wp_parse_args(
            (array) $instance,
            array(
                'title' => ''
            )
        );

        if ( ! empty( $instance['title'] ) ) {
            $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );
        }
        else {
            $title = '';
        }

        echo $before_widget;

        if ( ! empty( $title ) )
        {
            echo $before_title . $title . $after_title;
        }
 
        echo '<div class="brochures-widget">';
            echo '<ul>';
                for($i=1; $i<=6; $i++){
                    if( !empty($instance['file_icon_'.$i]) || !empty($instance['file_name_'.$i]))
                        echo '<li><a target="_blank" title="'.$instance['file_name_'.$i].'" href="'.$instance['file_url_'.$i].'"><i class="'.$instance['file_icon_'.$i].'"></i>'.$instance['file_name_'.$i].'</a></li>';
                }
            echo '</ul>'; 
        echo '</div>';
         
        echo $after_widget;
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array  An array of new settings as submitted by the admin
     * @param array  An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;
         
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        for($i=1; $i<=6; $i++){
            $instance['file_icon_'.$i] = sanitize_text_field( $new_instance['file_icon_'.$i] );
            $instance['file_name_'.$i] = sanitize_text_field( $new_instance['file_name_'.$i] );
            $instance['file_url_'.$i] = sanitize_text_field( $new_instance['file_url_'.$i] );
        }  
        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array  An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance )
    {
        $instance = wp_parse_args(
            (array) $instance,
            array(
                'title' => ''
            )
        );
        $title      = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'wpwage' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <?php
         for($i=1; $i<=6; $i++){
            $file_icon_i = isset($instance['file_icon_'.$i]) ? esc_attr($instance['file_icon_'.$i]) : '';
            $file_name_i = isset($instance['file_name_'.$i]) ? esc_attr($instance['file_name_'.$i]) : '';
            $file_url_i = isset($instance['file_url_'.$i]) ? esc_attr($instance['file_url_'.$i]) : '';
         ?>  
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'file_icon'.$i ) ); ?>"><?php esc_html_e( 'File Icon ', 'wpwage' ); ?><?php echo esc_attr($i);?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'file_icon_'.$i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'file_icon_'.$i ) ); ?>" type="text" value="<?php echo esc_attr( $file_icon_i ); ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'file_name_'.$i ) ); ?>"><?php esc_html_e( 'File Name ', 'wpwage' ); ?><?php echo esc_attr($i);?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'file_name_'.$i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'file_name_'.$i ) ); ?>" type="text" value="<?php echo esc_attr( $file_name_i ); ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'file_url_'.$i ) ); ?>"><?php esc_html_e( 'File url ', 'wpwage' ); ?><?php echo esc_attr($i);?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'file_url_'.$i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'file_url_'.$i ) ); ?>" type="text" value="<?php echo esc_url( $file_url_i ); ?>" />
            </p>
        <?php   
         }
         ?>  
        <?php
    }
}

add_action( 'widgets_init', create_function( '', "register_widget( 'Cms_Brochures_Widget' );" ) );