<?php
/**
 * Class CmsRecentPosts
 */
class CmsRecentPosts extends WP_Widget {
    /**
     * Widget Setup
     */
    function __construct() {
        $widget_ops = array('classname' => 'cms-recent-posts', 'description' => esc_html__('A widget that displays recent posts.', 'wpwage') );
        $control_ops = array('id_base' => 'cms_recent_posts');
        parent::__construct('cms_recent_posts', esc_html__('CMS Recent Posts', 'wpwage'), $widget_ops, $control_ops);
    }

    /**
     * Display Widget
     * @param array $args
     * @param array $instance
     */
    function widget($args, $instance) {
        extract($args);
        $title = $instance['title'];
        $posts = $instance['posts'];

        $args_query = array(
            'orderby' => 'ID',
            'order' => 'DESC',
            'posts_per_page' => $posts
        );
        $cms_recentposts = new WP_Query($args_query);

        echo ''.$before_widget;
        if($title) {
            echo $before_title.esc_attr($title).$after_title;
        }
        ?>
        <?php if ($cms_recentposts->have_posts()) : ?>
            <div class="latest-post-wrap">
                <ul class="cms-latest-post-wrap clearfix">
                <?php while($cms_recentposts->have_posts()): $cms_recentposts->the_post(); global $post; ?>
                    <li class="latest-post-item <?php echo (!empty($show_featured)) ? 'has-img' : '';?>">
                        
                        <?php if (has_post_thumbnail()): ?>
                            <div class="featured-wrap">
                                <?php the_post_thumbnail('thumbnail'); ?>
                            </div>
                        <?php endif ?>
                    
                       
                        
                          <div class="latest-item-info">
                                <a href="<?php echo esc_attr(get_the_permalink()); ?>" class="title"><?php the_title(); ?></a>
                                <div class="entry-date"><?php the_time('F d, Y') ?></div>

                        </div>
                    </li>
                <?php endwhile; ?>
                </ul>
            </div>
        <?php endif; ?>
        <!-- END WIDGET -->
        <?php
        echo ''.$after_widget;
        wp_reset_postdata();
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['posts'] = $new_instance['posts'];
        
        
        return $instance;
    }

    function form($instance) {


        $defaults = array('title' => 'Recent Posts', 'categories' => 'all', 'posts' => 2);
        $instance = wp_parse_args((array) $instance, $defaults); ?>

        <p>
            <label for="<?php echo esc_html($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'wpwage') ?></label>
            <input type="text" class="widefat" id="<?php echo esc_html($this->get_field_id('title')); ?>" name="<?php echo esc_html($this->get_field_name('title')); ?>" value="<?php echo esc_html($instance['title']); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_html($this->get_field_id('posts')); ?>"><?php esc_html_e('Number of posts:', 'wpwage') ?></label>
            <input type="text" class="widefat" id="<?php echo esc_html($this->get_field_id('posts')); ?>" name="<?php echo esc_html($this->get_field_name('posts')); ?>" value="<?php echo esc_html($instance['posts']); ?>" />
        </p>
        <p>
        
        </p>
    <?php
    }
}

register_widget('CmsRecentPosts');
?>