<?php defined( 'ABSPATH' ) or exit();
/**
 * Simple Image Widget
 * This widget allows you to pick image and show at the front-end with some options
 *
 * @author Stev Ngo <http://stevngodesign.com/>
 * @version 1.0
 */

class WageImagesWidget extends WP_Widget {
    /**
     * Constructor
     *
     * @return void
     **/
    function __construct() {
        parent::__construct(
            'cms_image_widget', // Base ID
            esc_html__( '[Wage] Image', 'wpwage' ), // Name
            array( 'description' => esc_html__( 'Add image with some options and optional link.', 'wpwage' ) ) // Args
        );
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts') );
    }

    /**
     * Enqueue admin scripts and styles
     *
     * @return void
     */
    function admin_scripts() {
        wp_enqueue_style( 'wage-images', get_template_directory_uri() . '/inc/widgets/image/widget.css' );
        wp_enqueue_media();
        wp_enqueue_script( 'wage-images', get_template_directory_uri() . '/inc/widgets/image/wg_upload.js', array( 'jquery', 'jquery-ui-core', 'jquery-ui-sortable', 'media-upload' ), '', true );
        wp_localize_script( 'wage-images', 'cmsImageWidgetFrame', array(
            'frame_title' => esc_html__( 'Select Image', 'wpwage' ),
            'button_title' => esc_html__( 'Insert Into Widget', 'wpwage' ),
            'frame_edit_title' => esc_html__( 'Change Image', 'wpwage' ),
            'button_edit_title' => esc_html__( 'Change', 'wpwage' )
        ) );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array  An array of standard parameters for widgets in this theme
     * @param array  An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance ) {
        extract( $args, EXTR_SKIP );
        $instance = wp_parse_args(
            (array) $instance,
            array(
                'title' => '',
                'image' => '',
                'link' => '',
                'textlink' => '',
                'align' => '',
                'target' => '',
                'size' => 'thumbnail',
                'desc' => '',
                'titleinbanner' => ''
            )
        );
        $allowed_html = array(
            'div' => array(
                'id' => array(),
                'class' => array()
            ),
            'aside' => array(
                'id' => array(),
                'class' => array()
            )
        );
        $allowed_html_title = array(
            'h2' => array(
                'id' => array(),
                'class' => array()
            ),
            'h3' => array(
                'id' => array(),
                'class' => array()
            ),
            'h4' => array(
                'id' => array(),
                'class' => array()
            ),
            'h5' => array(
                'id' => array(),
                'class' => array()
            ),
            'h6' => array(
                'id' => array(),
                'class' => array()
            )
        );
        if ( ! empty( $instance['title'] ) ) {
            $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );
        }
        else {
            $title = '';
        }

        echo $before_widget;
        if ( ! empty( $title ) ) {
            echo $before_title;
            echo esc_html( $title );
            echo $after_title;
        }
        $size = empty( $instance['size'] ) ? 'thumbnail' : strval( $instance['size'] );

        if ( ! empty( $instance['image'] ) ) {
            $image = ( is_numeric( $instance['image'] ) && $instance['image'] > 0 ) ? intval( $instance['image'] ) : 0;
            if ( $image > 0 ) {
                $alt = get_post_meta( $image, '_wp_attachment_image_alt', true );
                    $alt = empty( $alt ) ? '' : strval( $alt );
                    $image_src = wp_get_attachment_image_src( $image, $size );
                     $target = ( '' === $instance['target'] ) ? '_self' : '_blank';
                echo '<div class="wage-image-wg';
                if ( ! empty( $instance['align'] ) ) {
                    echo ' text-' . esc_attr( $instance['align'] );
                }
                echo '">';
                if (  empty( $instance['titleinbanner'] )  &&  empty( $instance['desc'] )  && empty( $instance['textlink']) ) {
                    if ( ! empty( $instance['link'] ) ) {
                       
                        echo '<a class="linkimage" href="' . esc_url( $instance['link'] ) . '" target="' . esc_attr( $target ) . '">';
                    }
                    
                    
                    if ( $image_src ) {
                        echo '<img src="' . esc_url( $image_src[0] ) . '" alt="' . esc_attr( $alt ) . '"/>';
                    }
                    if ( ! empty( $instance['link'] ) ) {
                        echo '</a>';
                    }
                }
                else  {
                    echo '<div class="content" style="background-image:url('.esc_url( $image_src[0]).')"><div class="content_inner">';
                
                        if ( ! empty( $instance['titleinbanner'] ) ) {
                            echo '<p class="titleinbanner"><strong>'.esc_html($instance['titleinbanner']).'</strong></p>';
                        }
                        if ( ! empty( $instance['desc'] ) ) {
                            echo '<p class="desc">'.esc_html($instance['desc']).'</p>';
                        }
                        if ( ! empty( $instance['textlink'] ) ) {
                            echo '<a class="linkinfo" href="' . esc_url( $instance['link'] ) . '" target="' . esc_attr( $target ) . '">'.esc_html($instance['textlink']).'</a>';
                        }
                
                    echo '</div></div>';
                }
                echo '</div>';
            }
        }
        echo $after_widget;
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array  An array of new settings as submitted by the admin
     * @param array  An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance ) {

        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['image'] = strip_tags( $new_instance['image'] );
        $instance['link'] = esc_url( strip_tags( $new_instance['link'] ) );
        $instance['textlink'] = strip_tags( $new_instance['textlink'] ) ;
        $instance['align'] = strip_tags( $new_instance['align'] );
        $instance['size'] = strip_tags( $new_instance['size'] );
        $instance['target'] = strip_tags( $new_instance['target'] );
        $instance['desc'] = strip_tags( $new_instance['desc'] );
        $instance['titleinbanner'] = strip_tags( $new_instance['titleinbanner'] );

        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array  An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance ) {
        $instance = wp_parse_args(
            (array) $instance,
            array(
                'title' => '',
                'image' => 0,
                'link' => '',
                'textlink' => '',
                'align' => '',
                'target' => '',
                'size' => 'thumbnail',
                'desc' => '',
                'titleinbanner' => ''
            )
        );

        $this_id    = $this->get_field_id( '' );
        $title      = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $image      = intval( $instance['image'] );
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'wpwage' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>"><?php esc_html_e( 'Columns:', 'wpwage' ); ?></label>
            <select class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'align' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>">
                <option value=""><?php esc_html_e( 'Default', 'wpwage' ); ?></option>
                <option value="left" <?php selected( "left", $instance['align'] ); ?>><?php esc_html_e( 'Left', 'wpwage' ); ?></option>
                <option value="center" <?php selected( "center", $instance['align'] ); ?>><?php esc_html_e( 'Center', 'wpwage' ); ?></option>
                <option value="right" <?php selected( "right", $instance['align'] ); ?>><?php esc_html_e( 'Right', 'wpwage' ); ?></option>
            </select>
        </p>
        <div class="cms-widget-image" id="<?php echo esc_attr( $this_id ); ?>">
            <label><?php esc_html_e( 'Image', 'wpwage' ); ?></label>
            <ul class="image"><?php
                $attachment_image = wp_get_attachment_image_src( $image, 'thumbnail' );
                if ( ! empty( $attachment_image ) ) {
                    echo '<li data-id="' . esc_attr( $image ) . '"'. 
                        ' style="background-image:url(' . esc_url( $attachment_image[0] ) . ');">';
                    echo '<a class="image-edit" href="#" onclick="cmsImageWidget.edit_image(event,\'' . esc_attr( $this_id ) . '\',' . esc_attr( $image ) . ')">' .
                            '<i class="dashicons dashicons-edit"></i>' .
                        '</a>';
                    echo '<a class="image-delete" href="#" onclick="cmsImageWidget.remove_image(event,\'' . esc_attr( $this_id ) . '\',' . esc_attr( $image ) . ');return false;">' .
                            '<i class="dashicons dashicons-trash"></i>' .
                        '</a>';
                    echo '</li>';
                }
            echo '<li data-id="0">';
            echo '<a class="image-add" href="#" onclick="cmsImageWidget.add_image(event,\'' . esc_attr( $this_id ) . '\');">' .
                    '<i class="dashicons dashicons-plus-alt"></i>' .
                '</a>';
            echo '</li>';
            ?></ul>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>"><?php esc_html_e( 'Image Size:', 'wpwage' ); ?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'size' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['size'] ); ?>" />
            </p>
            <p class="howto"><?php echo esc_html__( 'Add image size string, defaults include "thumbnail", "medium", "large", "full", or your defined size.', 'wpwage' ); ?></p>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php echo esc_html__( 'Link', 'wpwage' ); ?></label>
                <input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" value="<?php echo esc_url( $instance['link'] ); ?>" /></p>
             <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'textlink' ) ); ?>"><?php echo esc_html__( 'Text Link', 'wpwage' ); ?></label>
                <input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'textlink' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'textlink' ) ); ?>" value="<?php echo esc_attr( $instance['textlink'] ); ?>" /></p>

            <p class="howto"><?php echo esc_html__( 'Add link for image', 'wpwage' ); ?></p>
            <input type="hidden" name="<?php echo $this->get_field_name( 'image' ); ?>" id="<?php echo $this->get_field_id( 'image' ); ?>" value="<?php echo esc_attr( $instance['image'] ); ?>"/>
        </div>
        <p>
            <input id="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'target' ) ); ?>" type="checkbox" value="1" <?php checked( "1", $instance['target'] );  ?>/><label for="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>"><?php esc_html_e( 'Open link in new tab?', 'wpwage' ); ?></label>
        </p>
        <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'titleinbanner' ) ); ?>"><?php echo esc_html__( 'Title Banner', 'wpwage' ); ?></label>
                <input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'titleinbanner' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'titleinbanner' ) ); ?>" value="<?php echo esc_attr( $instance['titleinbanner'] ); ?>" /></p>
        <p class="howto"><?php echo esc_html__( 'Add description for image', 'wpwage' ); ?></p>
            <textarea name="<?php echo $this->get_field_name( 'desc' ); ?>" id="<?php echo $this->get_field_id( 'desc' ); ?>"><?php echo esc_attr( $instance['desc'] ); ?></textarea>
        <?php
    }
}

register_widget('WageImagesWidget');